"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const extractHeader = (req, key) => {
    const value = req.headers[key];
    if (!value || typeof value !== "string") {
        return undefined;
    }
    if (!value.length) {
        return undefined;
    }
    return value;
};
const extractAuthorizationToken = (req) => {
    const BearerToken = extractHeader(req, "authorization");
    if (!BearerToken) {
        return BearerToken;
    }
    const BearerTokenParts = BearerToken.split(" ");
    if (BearerTokenParts.length !== 2 || !BearerTokenParts[1]) {
        return undefined;
    }
    if (!BearerTokenParts[1].length) {
        return undefined;
    }
    return BearerTokenParts[1];
};
const extractSignature = (req) => extractHeader(req, "signature");
const extractProject = (req) => extractHeader(req, "project");
const extractEnvironment = (req) => extractHeader(req, "environment");
const getFullUrl = (req) => {
    const protocol = req.hostname.includes("localhost") ? "http" : "https";
    const port = protocol === "http" && process.env.PORT ? `:${process.env.PORT}` : "";
    return `${protocol}://${req.hostname}${port}${req.originalUrl}`;
};
const ExpressHelper = {
    extractHeader,
    extractAuthorizationToken,
    extractSignature,
    extractProject,
    extractEnvironment,
    getFullUrl,
};
exports.default = ExpressHelper;
